# Thermos

[![CI release check](https://github.com/tbonza/thermos/actions/workflows/main.yml/badge.svg)](https://github.com/tbonza/thermos/actions/workflows/main.yml)

Thermos is infrastructure for financial markets.

## Getting started

Build and test using Cmake.

## Thermos Philosophy

A thermos is a reliable container to keep your beverages warm. I use
mine almost daily to enjoy tea such as Yerba Mate. My thermos feels 
reliable to me because of the simple construction and use of durable 
materials like thick stainless steel. The thermos does one thing well 
which is similar to the Unix Philosophy.

Basics of the Unix philosophy, documented by Doug Mcllroy in the 
Bell System Technical Journal from 1978, described by [Eric S. 
Raymond who wrote The Art of Unix Programming](http://www.catb.org/~esr/writings/taoup/), "is bottom-up, not top down". Mcllroy 78 had this
to say at the time:

* Make each program do one thing well. To do a new job, 
  build afresh rather than complicate old programs by adding 
  new features.
* Expect the output of every program to become the input to another, 
  as yet unknown, program. Don't clutter output with extraneous 
  information. Avoid stringently columnar or binary input formats. 
  Don't insist on interactive input.
* Design and build software, even operating systems, to be tried 
  early, ideally within weeks. Don't hesitate to throw away the 
  clumsy parts and rebuild them.
* Use tools in preference to unskilled help to lighten a programming task, 
  even if you have to detour to build the tools and expect to throw some 
  of them out after you've finished using them.

Drawing inspiration from both my thermos and basics of the Unix Philosophy,
Thermos is intended to create a similar feeling for me in regards to 
infrastructure for financial markets.
